@@ -42,9 +42,23 @@ except ImportError:
     from urllib.parse import quote, unquote
 from optparse import OptionParser
 import logging
-import sys
+import sys, re
 import random
 
+# Colors for terminal
+W = '\033[1;97m'
+Y = '\033[1;93m'
+G = '\033[1;92m'
+R = '\033[1;91m'
+B = '\033[1;94m'
+C = '\033[1;96m'
+E = '\033[0m'
+
+# Windows based systems do not support ANSI sequences,
+# hence not displaying them.
+if 'win' in sys.platform:
+    W = Y = G = R = B = C = E = ''
+
 currentDir = os.getcwd()
 scriptDir = os.path.dirname(sys.argv[0]) or '.'
 os.chdir(scriptDir)
@@ -54,33 +68,28 @@ from wafw00f.lib.evillib import oururlparse, scrambledheader, waftoolsengine
 from wafw00f.manager import load_plugins
 from wafw00f.wafprio import wafdetectionsprio
 
-lackofart = r'''
-                                 ^     ^
-        _   __  _   ____ _   __  _    _   ____
-       ///7/ /.' \ / __////7/ /,' \ ,' \ / __/
-      | V V // o // _/ | V V // 0 // 0 // _/
-      |_n_,'/_n_//_/   |_n_,' \_,' \_,'/_/
-                                <
-                                ...'
+# Phew! WAF says a Woof! You know who's the good boy. :)
+woof = '''
+                 '''+W+'''______
+                '''+W+'''/      \\
+               '''+W+'''(  Woof! )
+                '''+W+'''\______/                      '''+R+''')
+                '''+W+''',,                           '''+R+''') ('''+Y+'''_
+           '''+Y+'''.-. '''+W+'''-    '''+G+'''_______                 '''+R+'''( '''+Y+'''|__|
+          '''+Y+'''()``; '''+G+'''|==|_______)                '''+R+'''.)'''+Y+'''|__|
+          '''+Y+'''/ ('        '''+G+'''/|\                  '''+R+'''(  '''+Y+'''|__|
+      '''+Y+'''(  /  )       '''+G+''' / | \                  '''+R+'''. '''+Y+'''|__|
+       '''+Y+'''\(_)_))      '''+G+'''/  |  \                   '''+Y+'''|__|'''+E+'''
 
     WAFW00F - Web Application Firewall Detection Tool
-
-    By Sandro Gauci && Wendel G. Henrique
-'''
-
+    \n'''
 
 class WafW00F(waftoolsengine):
-    """
-    WAF detection tool
-    """
 
     AdminFolder = '/Admin_Files/'
     xssstring = '<script>alert(1)</script>'
     dirtravstring = '../../../../etc/passwd'
     cleanhtmlstring = '<invalid>hello'
-    isaservermatch = [
-        'Forbidden ( The server denied the specified Uniform Resource Locator (URL). Contact the server administrator.  )',
-        'Forbidden ( The ISA Server denied the specified Uniform Resource Locator (URL)']
 
     def __init__(self, target='www.microsoft.com', port=80, ssl=False,
                  debuglevel=0, path='/', followredirect=True, extraheaders={}, proxy=False):
@@ -115,11 +124,11 @@ class WafW00F(waftoolsengine):
         return self.request(path=string, usecache=usecache, cacheresponse=cacheresponse)
 
     def cleanhtml(self, usecache=True, cacheresponse=True):
-        string = self.path + self.cleanhtmlstring + '.html'
+        string = self.path + '?htmli=' + self.cleanhtmlstring
         return self.request(path=string, usecache=usecache, cacheresponse=cacheresponse)
 
     def xssstandard(self, usecache=True, cacheresponse=True):
-        xssstringa = self.path + self.xssstring + '.html'
+        xssstringa = self.path + '?xss=' + self.xssstring
         return self.request(path=xssstringa, usecache=usecache, cacheresponse=cacheresponse)
 
     def protectedfolder(self, usecache=True, cacheresponse=True):
@@ -127,15 +136,10 @@ class WafW00F(waftoolsengine):
         return self.request(path=pfstring, usecache=usecache, cacheresponse=cacheresponse)
 
     def xssstandardencoded(self, usecache=True, cacheresponse=True):
-        xssstringa = self.path + quote(self.xssstring) + '.html'
-        return self.request(path=xssstringa, usecache=usecache, cacheresponse=cacheresponse)
+        xssstringb = self.path + quote(self.xssstring) + '.html'
+        return self.request(path=xssstringb, usecache=usecache, cacheresponse=cacheresponse)
 
-    def cmddotexe(self, usecache=True, cacheresponse=True):
-        # thanks j0e
-        string = self.path + 'cmd.exe'
-        return self.request(path=string, usecache=usecache, cacheresponse=cacheresponse)
-
-    attacks = [cmddotexe, directorytraversal, xssstandard, protectedfolder, xssstandardencoded]
+    attacks = [xssstandard, directorytraversal, protectedfolder, xssstandardencoded]
 
     def genericdetect(self, usecache=True, cacheresponse=True):
         knownflops = [
@@ -173,10 +177,10 @@ class WafW00F(waftoolsengine):
                 self.knowledge['generic']['reason'] = reason
                 self.knowledge['generic']['found'] = True
                 return True
-            response, responsebody = self._perform_and_check(self.normalrequest)
+            response, _ = self._perform_and_check(self.normalrequest)
             normalserver = response.getheader('Server')
             for attack in self.attacks:
-                response, responsebody = self._perform_and_check(lambda: attack(self))
+                response, _ = self._perform_and_check(lambda: attack(self))
                 attackresponse_server = response.getheader('Server')
                 if attackresponse_server:
                     if attackresponse_server != normalserver:
@@ -187,7 +191,7 @@ class WafW00F(waftoolsengine):
                         self.log.debug('normal response: %s' % normalserver)
                         reason = reasons[1]
                         reason += '\r\nThe server header for a normal response is "%s",' % normalserver
-                        reason += ' while the server header a response to an attack is "%s.",' % attackresponse_server
+                        reason += ' while the server header a response to an attack is "%s",' % attackresponse_server
                         self.knowledge['generic']['reason'] = reason
                         self.knowledge['generic']['found'] = True
                         return True
@@ -197,8 +201,8 @@ class WafW00F(waftoolsengine):
                     self.knowledge['generic']['found'] = True
                     return True
             for attack in self.attacks:
-                response, responsebody = self._perform_and_check(lambda: attack(self))
-                for h, v in response.getheaders():
+                response, _ = self._perform_and_check(lambda: attack(self))
+                for h, _ in response.getheaders():
                     if scrambledheader(h):
                         self.knowledge['generic']['reason'] = reasons[4]
                         self.knowledge['generic']['found'] = True
@@ -230,7 +234,7 @@ class WafW00F(waftoolsengine):
             r = request(self)
             if r is None:
                 return
-            response, responsebody = r
+            response, _ = r
             headerval = response.getheader(header)
             if headerval:
                 # set-cookie can have multiple headers, python gives it to us
@@ -241,11 +245,11 @@ class WafW00F(waftoolsengine):
                     headervals = [headerval]
                 for headerval in headervals:
                     if ignorecase:
-                        if re.match(match, headerval, re.IGNORECASE):
+                        if re.search(match, headerval, re.IGNORECASE):
                             detected = True
                             break
                     else:
-                        if re.match(match, headerval):
+                        if re.search(match, headerval):
                             detected = True
                             break
                 if detected:
@@ -306,7 +310,7 @@ def getheaders(fn):
 
 
 def main():
-    print(lackofart)
+    print(woof)
     parser = OptionParser(usage='%prog url1 [url2 [url3 ... ]]\r\nexample: %prog http://www.victim.org/')
     parser.add_option('-v', '--verbose', action='count', dest='verbose', default=0,
                       help='enable verbosity - multiple -v options increase verbosity')
@@ -354,7 +358,7 @@ def main():
         if pret is None:
             log.critical('The url %s is not well formed' % target)
             sys.exit(1)
-        (hostname, port, path, query, ssl) = pret
+        (hostname, port, path, _, ssl) = pret
         log.info('starting wafw00f on %s' % target)
         attacker = WafW00F(hostname, port=port, ssl=ssl,
                            debuglevel=options.verbose, path=path,
@@ -363,12 +367,12 @@ def main():
                            proxy=options.proxy)
         if attacker.normalrequest() is None:
             log.error('Site %s appears to be down' % target)
-            sys.exit(1)
+            continue
         if options.test:
             if options.test in attacker.wafdetections:
                 waf = attacker.wafdetections[options.test](attacker)
                 if waf:
-                    print('The site %s is behind a %s' % (target, options.test))
+                    print('The site %s is behind %s WAF.' % (target, options.test))
                 else:
                     print('WAF %s was not detected on %s' % (options.test, target))
             else:
@@ -378,7 +382,7 @@ def main():
         waf = attacker.identwaf(options.findall)
         log.info('Ident WAF: %s' % waf)
         if len(waf) > 0:
-            print('The site %s is behind a %s' % (target, ' and/or '.join(waf)))
+            print('The site %s is behind %s WAF.' % (target, ' and/or '.join(waf)))
         if (options.findall) or len(waf) == 0:
             print('Generic Detection results:')
             if attacker.genericdetect():
