@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
 
-NAME = 'Mission Control Application Shield'
+NAME = 'Mission Control Application Shield (Mission Control)'
 
 
 def is_waf(self):
     if self.matchheader(('server', 'Mission Control Application Shield')):
         return True
-    return False
+    return False
\ No newline at end of file
