@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
 
-NAME = 'NSFocus'
+NAME = 'NSFocus (NSFocus Global Inc.)'
 
 
 def is_waf(self):
     if self.matchheader(('server', 'NSFocus')):
         return True
-    return False
+    return False
\ No newline at end of file
